==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Andmehoidla pole saadaval",
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "Could not move %s - File with this name already exists" : "Ei saa liigutada faili %s - samanimeline fail on juba olemas",
    "Could not move %s" : "%s liigutamine ebaõnnestus",
    "Permission denied" : "Ligipääs keelatud",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"%s\" is an invalid file name." : "\"%s\" on vigane failinimi.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Vigane nimi, '\\', '/', '<', '>', ':', '\"', '|', '?' ja '*' pole lubatud.",
    "The target folder has been moved or deleted." : "Sihtkataloog on ümber tõstetud või kustutatud.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Nimi %s on juba kasutusel kataloogis %s. Palun vali mõni teine nimi.",
    "Not a valid source" : "Pole korrektne lähteallikas",
    "Server is not allowed to open URLs, please check the server configuration" : "Server ei võimalda URL-ide avamist, palun kontrolli serveri seadistust",
    "The file exceeds your quota by %s" : "Fail ületab sinu limiidi: %s",
    "Error while downloading %s to %s" : "Viga %s allalaadimisel %s",
    "Error when creating the file" : "Viga faili loomisel",
    "Folder name cannot be empty." : "Kataloogi nimi ei saa olla tühi.",
    "Error when creating the folder" : "Viga kataloogi loomisel",
    "Unable to set upload directory." : "Üleslaadimiste kausta määramine ebaõnnestus.",
    "Invalid Token" : "Vigane kontrollkood",
    "No file was uploaded. Unknown error" : "Ühtegi faili ei laetud üles. Tundmatu viga",
    "There is no error, the file uploaded with success" : "Ühtegi tõrget polnud, fail on üles laetud",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Üleslaetava faili suurus ületab php.ini poolt määratud upload_max_filesize suuruse:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail ületab MAX_FILE_SIZE suuruse, mis on HTML vormi jaoks määratud",
    "The uploaded file was only partially uploaded" : "Fail laeti üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei laetud üles",
    "Missing a temporary folder" : "Ajutiste failide kaust puudub",
    "Failed to write to disk" : "Kettale kirjutamine ebaõnnestus",
    "Not enough storage available" : "Saadaval pole piisavalt ruumi",
    "Upload failed. Could not find uploaded file" : "Üleslaadimine ebaõnnestus. Üleslaetud faili ei leitud",
    "Upload failed. Could not get file info." : "Üleslaadimine ebaõnnestus. Faili info hankimine ebaõnnestus.",
    "Invalid directory." : "Vigane kaust.",
    "Files" : "Failid",
    "All files" : "Kõik failid",
    "Favorites" : "Lemmikud",
    "Home" : "Kodu",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Total file size {size1} exceeds upload limit {size2}" : "Faili suurus {size1} ületab faili üleslaadimise mahu piirangu {size2}.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Could not get result from server." : "Serverist ei saadud tulemusi",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faili üleslaadimine on töös. Lehelt lahkumine katkestab selle üleslaadimise.",
    "URL cannot be empty" : "URL ei saa olla tühi",
    "{new_name} already exists" : "{new_name} on juba olemas",
    "Could not create file" : "Ei suuda luua faili",
    "Could not create folder" : "Ei suuda luua kataloogi",
    "Error fetching URL" : "Viga URL-i haaramisel",
    "Rename" : "Nimeta ümber",
    "Delete" : "Kustuta",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "Download" : "Lae alla",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Error moving file." : "Viga faili liigutamisel.",
    "Error moving file" : "Viga faili eemaldamisel",
    "Error" : "Viga",
    "Could not rename file" : "Ei suuda faili ümber nimetada",
    "Error deleting file." : "Viga faili kustutamisel.",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Krüpteerimisrakend on lubatud, kuid võtmeid pole lähtestatud. Palun logi välja ning uuesti sisse.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Vigane Krüpteerimisrakendi privaatvõti . Palun uuenda oma privaatse võtme parool oma personaasete seadete all taastamaks ligipääsu oma krüpteeritud failidele.",
    "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files." : "Krüpteering on keelatud, kuid sinu failid on endiselt krüpteeritud. Palun vaata oma personaalseid seadeid oma failide dekrüpteerimiseks.",
    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "Favorite" : "Lemmik",
    "%s could not be renamed as it has been deleted" : "%s ei saa ümber nimetada, kuna see on kustutatud",
    "%s could not be renamed" : "%s ümbernimetamine ebaõnnestus",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "File handling" : "Failide käsitlemine",
    "Maximum upload size" : "Maksimaalne üleslaadimise suurus",
    "max. possible: " : "maks. võimalik: ",
    "Save" : "Salvesta",
    "Settings" : "Seaded",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Kasuta seda aadressi <a href=\"%s\" target=\"_blank\">oma failidele ligipääsuks WebDAV kaudu</a>",
    "New" : "Uus",
    "New text file" : "Uus tekstifail",
    "Text file" : "Tekstifail",
    "New folder" : "Uus kaust",
    "Folder" : "Kaust",
    "From link" : "Allikast",
    "Upload" : "Lae üles",
    "Cancel upload" : "Tühista üleslaadimine",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "Files are being scanned, please wait." : "Faile skannitakse, palun oota.",
    "Currently scanning" : "Praegu skännimisel"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Andmehoidla pole saadaval",
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "Could not move %s - File with this name already exists" : "Ei saa liigutada faili %s - samanimeline fail on juba olemas",
    "Could not move %s" : "%s liigutamine ebaõnnestus",
    "Permission denied" : "Ligipääs keelatud",
    "The target folder has been moved or deleted." : "Sihtkataloog on ümber tõstetud või kustutatud.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Nimi %s on juba kasutusel kataloogis %s. Palun vali mõni teine nimi.",
    "Error when creating the file" : "Viga faili loomisel",
    "Error when creating the folder" : "Viga kataloogi loomisel",
    "Unable to set upload directory." : "Üleslaadimiste kausta määramine ebaõnnestus.",
    "Invalid Token" : "Vigane kontrollkood",
    "No file was uploaded. Unknown error" : "Ühtegi faili ei laetud üles. Tundmatu viga",
    "There is no error, the file uploaded with success" : "Ühtegi tõrget polnud, fail on üles laetud",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Üleslaetava faili suurus ületab php.ini poolt määratud upload_max_filesize suuruse:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail ületab MAX_FILE_SIZE suuruse, mis on HTML vormi jaoks määratud",
    "The uploaded file was only partially uploaded" : "Fail laeti üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei laetud üles",
    "Missing a temporary folder" : "Ajutiste failide kaust puudub",
    "Failed to write to disk" : "Kettale kirjutamine ebaõnnestus",
    "Not enough storage available" : "Saadaval pole piisavalt ruumi",
    "Upload failed. Could not find uploaded file" : "Üleslaadimine ebaõnnestus. Üleslaetud faili ei leitud",
    "Upload failed. Could not get file info." : "Üleslaadimine ebaõnnestus. Faili info hankimine ebaõnnestus.",
    "Invalid directory." : "Vigane kaust.",
    "Files" : "Failid",
    "All files" : "Kõik failid",
    "Favorites" : "Lemmikud",
    "Home" : "Kodu",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Total file size {size1} exceeds upload limit {size2}" : "Faili suurus {size1} ületab faili üleslaadimise mahu piirangu {size2}.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Could not get result from server." : "Serverist ei saadud tulemusi",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faili üleslaadimine on töös. Lehelt lahkumine katkestab selle üleslaadimise.",
    "{new_name} already exists" : "{new_name} on juba olemas",
    "Could not create file" : "Ei suuda luua faili",
    "Could not create folder" : "Ei suuda luua kataloogi",
    "Rename" : "Nimeta ümber",
    "Delete" : "Kustuta",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "No permission to delete" : "Kustutamiseks pole õigusi",
    "Download" : "Lae alla",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ei õnnestunud",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval. Palun kontrolli logifaile või võta ühendust administraatoriga",
    "Error moving file." : "Viga faili liigutamisel.",
    "Error moving file" : "Viga faili eemaldamisel",
    "Error" : "Viga",
    "Could not rename file" : "Ei suuda faili ümber nimetada",
    "Error deleting file." : "Viga faili kustutamisel.",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "{dirs} and {files}" : "{dirs} ja {files}",
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "A new file or folder has been <strong>created</strong>" : "Uus fail või kataloog on <strong>loodud</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fail või kataloog on <strong>muudetud</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fail või kataloog on <strong>kustutatud</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fail või kaust on <strong>taastatud</strong>",
    "You created %1$s" : "Sa tekitasid %1$s",
    "%2$s created %1$s" : "%2$s tekitatud %1$s",
    "%1$s was created in a public folder" : "%1$s lisati avalikku kausta",
    "You changed %1$s" : "Sa muutsid %1$s",
    "%2$s changed %1$s" : "%2$s muutis %1$s",
    "You deleted %1$s" : "Sa kustutasid %1$s",
    "%2$s deleted %1$s" : "%2$s kustutas %1$s",
    "You restored %1$s" : "Sa taastasid %1$s",
    "%2$s restored %1$s" : "%2$s taastas %1$s",
    "%s could not be renamed as it has been deleted" : "%s ei saa ümber nimetada, kuna see on kustutatud",
    "%s could not be renamed" : "%s ümbernimetamine ebaõnnestus",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "File handling" : "Failide käsitlemine",
    "Maximum upload size" : "Maksimaalne üleslaadimise suurus",
    "max. possible: " : "maks. võimalik: ",
    "Save" : "Salvesta",
    "Settings" : "Seaded",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Kasuta seda aadressi <a href=\"%s\" target=\"_blank\">oma failidele ligipääsuks WebDAV kaudu</a>",
    "New" : "Uus",
    "New text file" : "Uus tekstifail",
    "Text file" : "Tekstifail",
    "New folder" : "Uus kaust",
    "Folder" : "Kaust",
    "Upload" : "Lae üles",
    "Cancel upload" : "Tühista üleslaadimine",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "Files are being scanned, please wait." : "Faile skannitakse, palun oota.",
    "Currently scanning" : "Praegu skännimisel",
    "No favorites" : "Lemmikuid pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks"
},
"nplurals=2; plural=(n != 1);");
